import {useState} from 'react'
import './Login.css'
import Request from '../Request.jsx'
import {useTranslation} from "react-i18next";

function Login() {
    const error = useState(new URL(window.location).searchParams.get("message") || "");
    const uid = useState((window.localStorage && window.localStorage.getItem("ew_uid")) || "");
    const password = useState("");
    const { t } = useTranslation();

    function showError(message) {
        error[1](message);
    }

    const handleSubmit = async (event) => {
        event.preventDefault();
        if (!uid[0] || !password[0]) {
            showError(t('need_full_input'));
            return;
        }
        if (isNaN(uid[0])) {
            showError(t('uid_not_correct'));
            return;
        }
        if (window.localStorage) window.localStorage.setItem("ew_uid", uid[0]);
        let resp = await Request(
            "/api/webui/login",
            {
                uid: parseInt(uid[0]),
                password: password[0]
            }
        );
        if (resp.result === "OK") {
            window.location.href = "/home/";
        } else {
            showError(resp.message);
        }
    };
    
    const import_user = (e) => {
        e.preventDefault();
        window.location.href = "/import/";
    }

    const help = (e) => {
        e.preventDefault();
        window.location.href = "/help/";
    }
  
    return (
        <div id="login-form">
            <h1>{t('login')}</h1>
            <form>
                <label htmlFor="id">SIF2 ID:</label>
                <input type="text" id="id" name="id" onChange={(event) => {
                    uid[1](event.target.value)
                }} value={uid[0]}/>
                <label htmlFor="password">{t('transfer_passcode')}</label>
                <input type="password" id="password" name="password" onChange={(event) => {
                    password[1](event.target.value)
                }}/>
                <input type="submit" value={t('submit')} onClick={handleSubmit}/>
                <div id="sub_div">
                    <button onClick={import_user}>{t('import_user')}</button>
                    <br/><br/>
                    <button onClick={help}>{t('need_help')}</button>
                    <br/><br/>
                    {error[0] ? <p>Error: {error[0]} </p> : <p></p>}
                </div>
                <p>{t('ew_version')} 1.0.1 - <a href="https://git.zhushenwudi.top/zhushenwudi/ew">{t('view_source')}</a> - <a
                    href="https://git.zhushenwudi.top/zhushenwudi/ew/src/branch/main/LICENSE">{t('view_license')}</a></p>
            </form>
        </div>
    );
}

export default Login;
