import React from 'react'
import ReactDOM from 'react-dom/client'
import Login from './login/Login.jsx'
import Home from './home/Home.jsx'
import Import from './import/Import.jsx'
import Help from './help/Help.jsx'
import LanguageSwitcher from "./utils/LanguageSwitcher.jsx";
import {I18nextProvider} from 'react-i18next';
import i18next from 'i18next';
import enTranslation from './locales/en.json';
import zhTranslation from './locales/zh.json';

let Elem;
switch (window.location.pathname) {
    case "/":
        Elem = Login;
        break;
    case "/home/":
        Elem = Home;
        break;
    case "/import/":
        Elem = Import;
        break;
    case "/help/":
        Elem = Help;
        break;
    default:
        window.location.pathname = "/";
}

if (Elem) {
    const savedLanguage = localStorage.getItem('language') || 'zh';
    i18next.init({
        interpolation: {escapeValue: false},
        lng: savedLanguage,
        resources: {
            en: {translation: enTranslation},
            zh: {translation: zhTranslation},
        },
    }).then(() => {
        ReactDOM.createRoot(document.getElementById('root')).render(
            <React.StrictMode>
                <I18nextProvider i18n={i18next}>
                    <div style={{position: 'relative'}}>
                        <LanguageSwitcher/>
                        <Elem/>
                    </div>
                </I18nextProvider>
            </React.StrictMode>
        );
    });
}